"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShapeSkeleton = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const __1 = require("../..");
const ShapeAnnotation_1 = require("./ShapeAnnotation");
const ShapeHighlight_1 = require("./ShapeHighlight");
const ShapeRedaction_1 = require("./ShapeRedaction");
exports.ShapeSkeleton = (props) => {
    const permissions = __1.useDocumentPermissions();
    const [focused, setFocused] = react_1.useState(false);
    /**
     * Method that returns the shape dimensions as CSS properties
     * @param shape the shape instance
     * @param offsetX optional X offset
     * @param offsetY optional Y offset
     */
    const getShapeDimensions = (shape, offsetX = 0, offsetY = 0) => {
        return {
            top: shape.y * props.zoomRatio + offsetY * props.zoomRatio,
            left: shape.x * props.zoomRatio + offsetX * props.zoomRatio,
            width: shape.w * props.zoomRatio,
            height: shape.h * props.zoomRatio,
        };
    };
    /** event that will be triggered on resize */
    const onResized = (ev) => {
        const boundingBox = ev.currentTarget.getBoundingClientRect();
        const [shape, shapeType, zoomRatio] = [props.shape, props.shapeType, props.zoomRatio];
        const newSize = {
            w: boundingBox.width * (1 / zoomRatio),
            h: boundingBox.height * (1 / zoomRatio),
        };
        if (Math.abs(newSize.w - shape.w) > 1 || Math.abs(newSize.h - shape.h) > 1) {
            props.updateShapeData(shapeType, shape.guid, Object.assign(Object.assign({}, shape), newSize));
        }
    };
    /** onDragStart event handler for the Shape instance */
    const onDragStart = (ev) => {
        ev.dataTransfer.setData('shape', JSON.stringify({
            type: props.shapeType,
            shape: props.shape,
            offset: {
                width: ev.clientX - ev.currentTarget.getBoundingClientRect().left,
                height: ev.clientY - ev.currentTarget.getBoundingClientRect().top,
            },
        }));
    };
    /** onKeyPress event handler for deleting shapes */
    const handleKeyPress = (ev) => {
        switch (ev.key) {
            case 'Backspace':
            case 'Delete':
                permissions.canEdit && props.removeShape(props.shapeType, props.shape.guid);
                break;
            default:
                break;
        }
    };
    /** onFocus event handler that updates the 'focused' property */
    const onFocus = () => {
        setFocused(true);
    };
    /** onBlur event handler that updates the 'focused' property */
    const onBlur = (ev) => {
        var _a;
        setFocused(false);
        if (props.shapeType === 'annotations') {
            props.updateShapeData('annotations', props.shape.guid, Object.assign(Object.assign({}, props.shape), { text: (_a = ev.currentTarget.innerText) === null || _a === void 0 ? void 0 : _a.trim() }));
        }
    };
    return (react_1.default.createElement("div", { onClickCapture: (ev) => ev.stopPropagation(), style: { filter: focused ? 'contrast(.9) brightness(1.1)' : '' }, onKeyUp: handleKeyPress, onFocus: onFocus, onBlur: onBlur }, props.shapeType === 'annotations' ? (react_1.default.createElement(ShapeAnnotation_1.ShapeAnnotation, { shape: props.shape, zoomRatio: props.zoomRatio, focused: focused, onDragStart: onDragStart, onResized: onResized, getShapeDimensions: getShapeDimensions, updateShapeData: props.updateShapeData, removeShape: props.removeShape })) : props.shapeType === 'redactions' ? (react_1.default.createElement(ShapeRedaction_1.ShapeRedaction, { shape: props.shape, onDragStart: onDragStart, onResized: onResized, getShapeDimensions: getShapeDimensions })) : (react_1.default.createElement(ShapeHighlight_1.ShapeHighlight, { shape: props.shape, onDragStart: onDragStart, onResized: onResized, getShapeDimensions: getShapeDimensions }))));
};
//# sourceMappingURL=ShapeSkeleton.js.map