"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShapesWidget = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
const shapes_1 = require("../shapes");
const style_1 = require("./style");
/**
 * Page widget component for displaying shapes on a page
 */
exports.ShapesWidget = (props) => {
    var _a, _b;
    const permissions = hooks_1.useDocumentPermissions();
    const viewerState = hooks_1.useViewerState();
    const { documentData, updateDocumentData } = hooks_1.useDocumentData();
    const comments = hooks_1.useComments();
    const commentState = hooks_1.useCommentState();
    const visibleShapes = {
        redactions: documentData.shapes.redactions.filter((r) => r.imageIndex === props.page.Index),
        highlights: documentData.shapes.highlights.filter((r) => r.imageIndex === props.page.Index),
        annotations: documentData.shapes.annotations.filter((r) => r.imageIndex === props.page.Index),
    };
    const visibleComments = [
        ...comments.comments.filter((comment) => comment.page === props.page.Index),
        ...(props.page.Index !== undefined && ((_a = commentState.draft) === null || _a === void 0 ? void 0 : _a.page) === ((_b = props.page) === null || _b === void 0 ? void 0 : _b.Index) ? [commentState.draft] : []),
    ];
    const removeShape = react_1.useCallback((shapeType, guid) => {
        ;
        documentData.shapes[shapeType] = documentData.shapes[shapeType].filter((s) => s.guid !== guid);
        updateDocumentData(documentData);
        viewerState.updateState({ hasChanges: true });
    }, [documentData, updateDocumentData, viewerState]);
    const updateShapeData = react_1.useCallback((shapeType, guid, shapeChange) => {
        ;
        documentData.shapes[shapeType] = documentData.shapes[shapeType].map((s) => {
            if (s.guid === guid) {
                return Object.assign(Object.assign({}, s), shapeChange);
            }
            return s;
        });
        viewerState.updateState({ hasChanges: true });
        updateDocumentData(documentData);
    }, [documentData, updateDocumentData, viewerState]);
    const onDrop = react_1.useCallback((ev) => {
        if (permissions.canEdit) {
            ev.preventDefault();
            const shapeData = JSON.parse(ev.dataTransfer.getData('shape'));
            const boundingBox = ev.currentTarget.getBoundingClientRect();
            updateShapeData(shapeData.type, shapeData.shape.guid, Object.assign(Object.assign({}, shapeData.shape), { imageIndex: props.page.Index, x: (ev.clientX - boundingBox.left - shapeData.offset.width) * (1 / props.zoomRatio), y: (ev.clientY - boundingBox.top - shapeData.offset.height) * (1 / props.zoomRatio) }));
        }
    }, [permissions.canEdit, props.page.Index, props.zoomRatio, updateShapeData]);
    return (react_1.default.createElement("div", { style: {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            zIndex: 1,
        }, onDrop: onDrop, onDragOver: (ev) => ev.preventDefault() },
        viewerState.showComments &&
            visibleComments.length > 0 &&
            visibleComments.map((marker) => (react_1.default.createElement(style_1.CommentMarker, { onClick: () => commentState.setActiveComment(marker.id), isSelected: marker.id === commentState.activeCommentId, zoomRatio: props.zoomRatio, marker: marker, key: marker.id }))),
        react_1.default.createElement("div", null,
            permissions.canHideRedaction &&
                viewerState.showRedaction &&
                visibleShapes.redactions.map((redaction, index) => {
                    return (react_1.default.createElement(shapes_1.ShapeSkeleton, { key: index, shape: redaction, shapeType: "redactions", zoomRatio: props.zoomRatio, updateShapeData: updateShapeData, removeShape: removeShape }));
                }),
            viewerState.showShapes &&
                visibleShapes.annotations.map((annotation, index) => {
                    return (react_1.default.createElement(shapes_1.ShapeSkeleton, { key: index, shape: annotation, shapeType: "annotations", zoomRatio: props.zoomRatio, updateShapeData: updateShapeData, removeShape: removeShape }));
                }),
            viewerState.showShapes &&
                visibleShapes.highlights.map((highlight, index) => {
                    return (react_1.default.createElement(shapes_1.ShapeSkeleton, { key: index, shape: highlight, shapeType: "highlights", zoomRatio: props.zoomRatio, updateShapeData: updateShapeData, removeShape: removeShape }));
                }))));
};
//# sourceMappingURL=Shapes.js.map